==> recommonmark_0.6.0+ds.orig.tar.xz: recommonmark-0.6.0/CHANGELOG.md <==

Version 0.6.0
-------------

Date: 2019-08-09

-   [@RaptorCZ](http://github.com/RaptorCZ): Process linebreaks and
    convert them to br element.
    ([\#162](https://github.com/readthedocs/recommonmark/pull/162))
-   [@gibfahn](http://github.com/gibfahn): Remove URL quoting from refs
    before passing to Sphinx
    ([\#158](https://github.com/readthedocs/recommonmark/pull/158))
-   [@dandersson](http://github.com/dandersson): Use image description
    text as \"alt\", drop title
    ([\#150](https://github.com/readthedocs/recommonmark/pull/150))
-   [@annegentle](http://github.com/annegentle): Clarify the specifics
    of Auto Toc Tree
    ([\#149](https://github.com/readthedocs/recommonmark/pull/149))
-   [@loganrosen](http://github.com/loganrosen): Bump dependency on
    commonmark to \>= 0.8.1
    ([\#147](https://github.com/readthedocs/recommonmark/pull/147))
-   [@codejamninja](http://github.com/codejamninja): Use official
    gitignore template
    ([\#140](https://github.com/readthedocs/recommonmark/pull/140))
-   [@dotlambda](http://github.com/dotlambda): Include all test files in
    PyPI tarball
    ([\#128](https://github.com/readthedocs/recommonmark/pull/128))
-   [@tk0miya](http://github.com/tk0miya): Register a parser class using
    new Sphinx API; add\_source\_suffix
    ([\#113](https://github.com/readthedocs/recommonmark/pull/113))

## Changelog

## 0.4.0 (in development)

Set rawsource value for each nodes.

## 0.3.0 (2016-01-15)

Fix compatability with Commonmark-Py 0.6.0

==> recommonmark_0.7.1+ds.orig.tar.xz: recommonmark-0.7.1/CHANGELOG.md <==
Development
----------

Version 0.7.0
-------------

Date: 2020-12-17

-   [limasierra](https://github.com/limasierra): Bugfix: External links to 'supported' files 
    lose their file extension ([\#181](https://github.com/readthedocs/recommonmark/pull/181))
 

Version 0.6.0
-------------

Date: 2019-08-09

-   [@RaptorCZ](http://github.com/RaptorCZ): Process linebreaks and
    convert them to br element.
    ([\#162](https://github.com/readthedocs/recommonmark/pull/162))
-   [@gibfahn](http://github.com/gibfahn): Remove URL quoting from refs
    before passing to Sphinx
    ([\#158](https://github.com/readthedocs/recommonmark/pull/158))
-   [@dandersson](http://github.com/dandersson): Use image description
    text as \"alt\", drop title
    ([\#150](https://github.com/readthedocs/recommonmark/pull/150))
-   [@annegentle](http://github.com/annegentle): Clarify the specifics
    of Auto Toc Tree
    ([\#149](https://github.com/readthedocs/recommonmark/pull/149))
-   [@loganrosen](http://github.com/loganrosen): Bump dependency on
    commonmark to \>= 0.8.1
    ([\#147](https://github.com/readthedocs/recommonmark/pull/147))
-   [@codejamninja](http://github.com/codejamninja): Use official
    gitignore template
    ([\#140](https://github.com/readthedocs/recommonmark/pull/140))
-   [@dotlambda](http://github.com/dotlambda): Include all test files in
    PyPI tarball
    ([\#128](https://github.com/readthedocs/recommonmark/pull/128))
-   [@tk0miya](http://github.com/tk0miya): Register a parser class using
    new Sphinx API; add\_source\_suffix
    ([\#113](https://github.com/readthedocs/recommonmark/pull/113))

## Changelog

## 0.4.0 (in development)

Set rawsource value for each nodes.

## 0.3.0 (2016-01-15)

Fix compatability with Commonmark-Py 0.6.0
